# Anixart API wrapper
## Описание

Враппер для использования Anixart API.\
Библиотека создана только для ознакомления c API.

**Автор не поддерживает и презирает создание авторегов / ботов для накрутки / спам ботов.**

### Установка

```shell
pip install anixart
```

### Как работать с библиотекой
#### Вся документация в папке [docs](https://github.com/SantaSpeen/anixart/tree/master/docs) 
_(Пока что не дошли руки написать доки, гляньте в [examples](https://github.com/SantaSpeen/anixart/tree/master/examples) как работать с библиотекой)_


## Обратная связь

Если у вас возникли вопросы, или вы хотите каким-либо образом помочь автору вы можете написать ему в телеграм: [@SantaSpeen](https://t.me/SantaSpeen)

<br/>

## License

Проект распространяется под лицензией `FPA License`. Подробнее в [LICENSE](LICENSE)
